<?php
if ( ! class_exists( 'brutalist_dash_page' ) ) {
	class brutalist_dash_page {
		private $config;
		private $theme_name;
		private $theme_slug;
		private $theme;
		private $menu_name;
		private $page_name;
		private $tabs;
		private $notification;
		private static $instance;

		public static function init( $config ) {
			if ( ! isset( self::$instance ) && ! ( self::$instance instanceof brutalist_dash_page ) ) {
				self::$instance = new brutalist_dash_page;
				if ( ! empty( $config ) && is_array( $config ) ) {
					self::$instance->config = $config;
					self::$instance->setup_config();
					self::$instance->setup_actions();
				}
			}
		}

		// Setup
		public function setup_config() {
			$theme = wp_get_theme();
			if ( is_child_theme() ) {
				$this->theme_name = $theme->parent()->get( 'Name' );
				$this->theme      = $theme->parent();
			} else {
				$this->theme_name = $theme->get( 'Name' );
				$this->theme      = $theme->parent();
			}
			$this->theme_slug    = $theme->get_template();
			$this->menu_name     = isset( $this->config['menu_name'] ) ? $this->config['menu_name'] : $this->theme_name;
			$this->page_name     = isset( $this->config['page_name'] ) ? $this->config['page_name'] : $this->theme_name;
			$this->notification  = isset( $this->config['notification'] ) ? $this->config['notification'] : ( '<p>' . sprintf( 'Thank you for choosing %1$s! To fully take advantage of the theme, please see %2$sstart page%3$s.', $this->theme_name, '<a href="' . esc_url( admin_url( 'themes.php?page=' . $this->theme_slug . '-welcome' ) ) . '">', '</a>' ) . '</p><p><a href="' . esc_url( admin_url( 'themes.php?page=' . $this->theme_slug . '-welcome' ) ) . '" class="button" style="text-decoration: none;">' . sprintf( 'Get started with %s', $this->theme_name ) . '</a></p>' );
			$this->tabs          = isset( $this->config['tabs'] ) ? $this->config['tabs'] : array();

		}

		// Actions
		public function setup_actions() {
			add_action( 'admin_menu', array( $this, 'register' ) );
			// activation notice
			add_action( 'load-themes.php', array( $this, 'activation_admin_notice' ) );
			// enqueue scripts
			add_action( 'admin_enqueue_scripts', array( $this, 'style_and_scripts' ) );
			// ajax callback for dismissible required actions
			add_action( 'brutalist_dash_page_dismiss_required_action', array( $this, 'dismiss_required_action_callback' ) );
		}

		public function hide_required( $value, $tab ) {
			if ( $tab != 'recommended_actions' ) {
				return $value;
			}
			$required = $this->get_required_actions();
			if ( count( $required ) == 0 ) {
				return false;
			} else {
				return true;
			}
		}


		// Register menu item in Dashboard > Appearance
		function register() {
			if ( ! empty( $this->menu_name ) && ! empty( $this->page_name ) ) {
				add_theme_page(
					$this->menu_name, $this->page_name, 'activate_plugins', $this->theme_slug . '-welcome', array(
						$this,
						'brutalist_dash_page_render',
					)
				);
			}
		}

		// Successful activation notice
		public function activation_admin_notice() {
			global $pagenow;
			if ( is_admin() && ( 'themes.php' == $pagenow ) && isset( $_GET['activated'] ) ) {
				add_action( 'admin_notices', array( $this, 'brutalist_welcome_notice' ), 99 );
			}
		}

		public function brutalist_welcome_notice() {
			if ( ! empty( $this->notification ) ) {
				echo '<div class="updated notice is-dismissible">';
				echo wp_kses_post( $this->notification );
				echo '</div>';
			}
		}

		// Render dashboard page content
		public function brutalist_dash_page_render() {

			if ( ! empty( $this->config['welcome_title'] ) ) {
				$welcome_title = $this->config['welcome_title'];
			}
			if ( ! empty( $this->config['welcome_content'] ) ) {
				$welcome_content = $this->config['welcome_content'];
			}

			if ( ! empty( $welcome_title ) || ! empty( $welcome_content ) || ! empty( $this->tabs ) ) {

				echo '<div class="wrap about-wrap epsilon-wrap">';

				if ( ! empty( $welcome_title ) ) {
					echo '<h1>' . esc_html( $welcome_title ) . '</h1>';
				}
				if ( ! empty( $welcome_content ) ) {
					echo '<div class="about-text">' . wp_kses_post( $welcome_content ) . '</div>';
				}

				echo '<a target="_blank" href="https://brutalistthemes.com/" class="wp-badge epsilon-welcome-logo"></a>';

				// Display tabs
				if ( ! empty( $this->tabs ) ) {
					$active_tab = isset( $_GET['tab'] ) ? sanitize_text_field( wp_unslash( $_GET['tab'] ) ) : 'getting_started';

					echo '<h2 class="nav-tab-wrapper" id="brutalisttabs">';
					foreach ( $this->tabs as $tab_key => $tab_name ) {
						printf(
							'<a href="%2$s" class="tab-link nav-tab ' . ( $active_tab == $tab_key ? 'nav-tab-active' : '' ) . '" data-tab="%1$s">%3$s</a>',
							esc_attr( $tab_key ),
							esc_url( '#' . $tab_key ),
							esc_html( $tab_name )
						);
					}
					echo '</h2>';

					// Current tab
					if ( method_exists( $this, $active_tab ) ) {
						$this->$active_tab();
					}
				}

				echo '</div>';
			}
		}

		// Tabs content
		public function getting_started() {
			// Getting Started tab
			if ( ! empty( $this->config['getting_started'] ) ) {
				$getting_started = $this->config['getting_started'];
				if ( ! empty( $getting_started ) ) {
					echo '<div class="tab-content nav-tab-active" id="getting_started"><div class="grid__wrapper">';
					foreach ( $getting_started as $getting_started_item ) {
						echo '<div>';
						if ( ! empty( $getting_started_item['title'] ) ) {
							echo '<h3>' . esc_html( $getting_started_item['title'] ) . '</h3>';
						}
						if ( ! empty( $getting_started_item['text'] ) ) {
							echo '<p>' . esc_html( $getting_started_item['text'] ) . '</p>';
						}
						if ( ! empty( $getting_started_item['button_link'] ) && ! empty( $getting_started_item['button_label'] ) ) {
							echo '<p>';
							$button_class = '';
							if ( $getting_started_item['is_button'] ) {
								$button_class = 'button button-primary';
							}
							$button_new_tab = '_self';
							if ( isset( $getting_started_item['is_new_tab'] ) ) {
								if ( $getting_started_item['is_new_tab'] ) {
									$button_new_tab = '_blank';
								}
							}
							echo '<a target="' . esc_attr( $button_new_tab ) . '" href="' . esc_url( $getting_started_item['button_link'] ) . '"class="' . esc_attr( $button_class ) . '">' . esc_html( $getting_started_item['button_label'] ) . '</a>';
							echo '</p>';
						}
						echo '</div>';
					}
					echo '</div></div>';
				}
			}

			// Free vs PRO tab
			$lite_pro = isset( $this->config['lite_pro'] ) ? $this->config['lite_pro'] : array();
			if ( ! empty( $lite_pro ) ) {
				if ( ! empty( $lite_pro['free_name'] ) && ! empty( $lite_pro['pro_name'] ) && ! empty( $lite_pro['features'] ) && is_array( $lite_pro['features'] ) ) {
					echo '<div class="tab-content" id="lite_pro"><div class="grid__wrapper">';
					echo '<div></div>';
					echo '<div><h3>' . esc_html( $lite_pro['free_name'] ) . '</h3></div>';
					echo '<div><h3>' . esc_html( $lite_pro['pro_name'] ) . '</h3></div>';
					foreach ( $lite_pro['features'] as $feature ) {
						if ( ! empty( $feature['title'] ) || ! empty( $feature['description'] ) ) {
							echo '<div>';
							if ( ! empty( $feature['title'] ) ) {
								echo '<h3>' . wp_kses_post( $feature['title'] ) . '</h3>';
							}
							if ( ! empty( $feature['description'] ) ) {
								echo '<p>' . wp_kses_post( $feature['description'] ) . '</p>';
							}
							echo '</div>';
						}
						if ( ! empty( $feature['is_in_lite'] ) && ( $feature['is_in_lite'] == 'true' ) ) {
							echo '<div class="green"><span class="dashicons-before dashicons-yes"></span></div>';
						} else {
							echo '<div class="red"><span class="dashicons-before dashicons-no-alt"></span></div>';
						}
						if ( ! empty( $feature['is_in_pro'] ) && ( $feature['is_in_pro'] == 'true' ) ) {
							echo '<div class="green"><span class="dashicons-before dashicons-yes"></span></div>';
						} else {
							echo '<div class="red"><span class="dashicons-before dashicons-no-alt"></span></div>';
						}
					}
					if ( ! empty( $lite_pro['pro_link'] ) && ! empty( $lite_pro['pro_label'] ) ) {
						echo '<div></div>';
						echo '<div><a href="' . esc_url( $lite_pro['pro_link'] ) . '" target="_blank" class="button button-primary button-hero">' . wp_kses_post( $lite_pro['pro_label'] ) . '</a></div>';
					}
					echo '</div></div>';
				}
			}
		}

		// CSS and JS
		public function style_and_scripts() {
			wp_enqueue_style( 'brutalist-dash-page-css', get_template_directory_uri() . '/welcome/brutalist_dash_page.css', array(), STEAMPUNK_VERSION );
			wp_enqueue_script( 'brutalist-dash-page-js', get_template_directory_uri() . '/welcome/brutalist_dash_page.js', array( 'jquery' ), STEAMPUNK_VERSION);
		}
	}
}
